==> v1.2018.0.zip: plantuml/src/h/ST_label_params_t.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of Smetana.
 * Smetana is a partial translation of Graphviz/Dot sources from C to Java.
 *
 * (C) Copyright 2009-2017, Arnaud Roques
 *
 * This translation is distributed under the same Licence as the original C program:
 * 
 *************************************************************************
 * Copyright (c) 2011 AT&T Intellectual Property 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors: See CVS logs. Details at http://www.graphviz.org/
 *************************************************************************
 *
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS ECLIPSE PUBLIC
 * LICENSE ("AGREEMENT"). [Eclipse Public License - v 1.0]
 * 
 * ANY USE, REPRODUCTION OR DISTRIBUTION OF THE PROGRAM CONSTITUTES
 * RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.
 * 
 * You may obtain a copy of the License at
 * 
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package h;

import h.ST_label_params_t.Amp;

import java.util.Arrays;
import java.util.List;

import smetana.core.UnsupportedStarStruct;
import smetana.core.UnsupportedStructAndPtr;
import smetana.core.__ptr__;
import smetana.core.__struct__;
import smetana.core.amiga.StarStruct;

public class ST_label_params_t extends UnsupportedStructAndPtr {

	private final StarStruct parent;

	public ST_label_params_t() {
		this(null);
	}

	public ST_label_params_t(StarStruct parent) {
		this.parent = parent;
	}

	// "typedef struct",
	// "{",
	private final ST_boxf bb = new ST_boxf(this);
	private boolean force;

	// "}",
	// "label_params_t");

	@Override
	public StarStruct amp() {
		return new Amp();
	}

	public class Amp extends UnsupportedStarStruct {

	}

	@Override
	public void setStruct(String fieldName, __struct__ newData) {
		if (fieldName.equals("bb")) {
			this.bb.copyDataFrom(newData);
			return;
		}
		super.setStruct(fieldName, newData);
	}

	@Override
	public void setBoolean(String fieldName, boolean data) {
		if (fieldName.equals("force")) {
			this.force = data;
			return;
		}
		super.setBoolean(fieldName, data);
	}
}

// typedef struct {
// boxf bb; /* Bounding box of all objects */
// unsigned char force; /* If true, all labels must be placed */
// } label_params_t;

==> v1.2018.12.zip: plantuml/src/h/ST_label_params_t.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of Smetana.
 * Smetana is a partial translation of Graphviz/Dot sources from C to Java.
 *
 * (C) Copyright 2009-2017, Arnaud Roques
 *
 * This translation is distributed under the same Licence as the original C program:
 * 
 *************************************************************************
 * Copyright (c) 2011 AT&T Intellectual Property 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors: See CVS logs. Details at http://www.graphviz.org/
 *************************************************************************
 *
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS ECLIPSE PUBLIC
 * LICENSE ("AGREEMENT"). [Eclipse Public License - v 1.0]
 * 
 * ANY USE, REPRODUCTION OR DISTRIBUTION OF THE PROGRAM CONSTITUTES
 * RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.
 * 
 * You may obtain a copy of the License at
 * 
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package h;

import smetana.core.UnsupportedStarStruct;
import smetana.core.UnsupportedStructAndPtr;
import smetana.core.__struct__;
import smetana.core.amiga.StarStruct;

public class ST_label_params_t extends UnsupportedStructAndPtr {

	private final StarStruct parent;

	public ST_label_params_t() {
		this(null);
	}

	public ST_label_params_t(StarStruct parent) {
		this.parent = parent;
	}

	// "typedef struct",
	// "{",
	public final ST_boxf bb = new ST_boxf(this);
	public boolean force;

	// "}",
	// "label_params_t");

	@Override
	public void setStruct(String fieldName, __struct__ newData) {
		if (fieldName.equals("bb")) {
			this.bb.copyDataFrom(newData);
			return;
		}
		super.setStruct(fieldName, newData);
	}
	
	@Override
	public __struct__ getStruct(String fieldName) {
		if (fieldName.equals("bb")) {
			return bb;
		}
		return super.getStruct(fieldName);
	}


	@Override
	public boolean getBoolean(String fieldName) {
		if (fieldName.equals("force")) {
			return this.force;
		}
		return super.getBoolean(fieldName);
	}

	@Override
	public void setBoolean(String fieldName, boolean data) {
		if (fieldName.equals("force")) {
			this.force = data;
			return;
		}
		super.setBoolean(fieldName, data);
	}
}

// typedef struct {
// boxf bb; /* Bounding box of all objects */
// unsigned char force; /* If true, all labels must be placed */
// } label_params_t;
